@@ -58,14 +58,19 @@ class TestDbtCliSolids:
         assert len(table_materializations) == 4
 
     def test_dbt_cli_run_with_extra_config(
-        self, dbt_seed, test_project_dir, dbt_config_dir
+        self, dbt_seed, test_project_dir, dbt_config_dir, dbt_target_dir, monkeypatch
     ):  # pylint: disable=unused-argument
+
+        # Specify dbt target path
+        monkeypatch.setenv("DBT_TARGET_PATH", dbt_target_dir)
+
         test_solid = configured(dbt_cli_run, name="test_solid")(
             {
                 "project-dir": test_project_dir,
                 "profiles-dir": dbt_config_dir,
                 "threads": 1,
                 "models": ["least_caloric"],
+                "target-path": dbt_target_dir,
                 "fail-fast": True,
             }
         )
@@ -83,6 +88,24 @@ class TestDbtCliSolids:
         result = execute_solid(test_solid)
         assert result.success
 
+    def test_dbt_cli_test_with_extra_confg(
+        self, dbt_seed, test_project_dir, dbt_config_dir, dbt_target_dir, monkeypatch
+    ):  # pylint: disable=unused-argument
+
+        # Specify dbt target path
+        monkeypatch.setenv("DBT_TARGET_PATH", dbt_target_dir)
+
+        test_solid = configured(dbt_cli_test, name="test_solid")(
+            {
+                "project-dir": test_project_dir,
+                "profiles-dir": dbt_config_dir,
+                "target-path": dbt_target_dir,
+            }
+        )
+
+        result = execute_solid(test_solid)
+        assert result.success
+
     def test_dbt_cli_snapshot(
         self, dbt_seed, test_project_dir, dbt_config_dir
     ):  # pylint: disable=unused-argument
